@@ -148,7 +148,7 @@ class Mention(Printable):
 
     def string(self):
         """"""
-        return f"{self.start}:{self.length}:{self.user.number}"
+        return f"{self.start}:{self.length}:{self.user.uuid}"
 
 
 class Reaction(Printable):
